@@ -14,7 +14,7 @@
 
 import click
 
-from roe.utilities import utils as roe_utils
+from roe.utilities.running_utils import deploy
 
 
 @click.command()
@@ -25,5 +25,5 @@ from roe.utilities import utils as roe_utils
 @click.argument('folder_path')
 def cli(local, package_name, folder_path, port, quick):
     """Deploy and start a package."""
-    roe_utils.deploy(local, package_name, folder_path, port, quick_deploy=quick)
+    deploy(local, package_name, folder_path, port, quick_deploy=quick)
     return
