@@ -14,7 +14,7 @@
 
 import click
 
-from roe.utilities import utils as roe_utils
+from roe.utilities.running_utils import start
 
 
 @click.command()
@@ -23,5 +23,5 @@ from roe.utilities import utils as roe_utils
 @click.option("-p", "--package_name", type=str, help="Name of package")
 def cli(local, package_name, all):
     """Start a stopped(exited status) package."""
-    roe_utils.start(local, package_name, all)
+    start(local, package_name, all)
     return
