@@ -14,7 +14,7 @@
 
 import click
 
-from roe.utilities import utils as roe_utils
+from roe.utilities.running_utils import stop
 
 
 @click.command()
@@ -23,5 +23,5 @@ from roe.utilities import utils as roe_utils
 @click.option("-p", "--package_name", type=str, help="Name of package")
 def cli(local, package_name, all):
     """Stop a running package."""
-    roe_utils.stop(local, package_name, all, quick_deploy=False)
+    stop(local, package_name, all)
     return
