@@ -14,7 +14,7 @@
 
 import click
 
-from roe.utilities import utils as roe_utils
+from roe.utilities.running_utils import undeploy
 
 
 @click.command()
@@ -26,5 +26,5 @@ def cli(local, package_name, all):
     Undeploy a Package or all packages.
     If the package is running, you will be asked if you want to stop and delete it.
     """
-    roe_utils.undeploy(local, package_name, all)
+    undeploy(local, package_name, all)
     return
