@@ -316,6 +316,8 @@ def start_package(roe_client: RoeClient, package_name: str):
                 failure_state_logs(roe_client, package_name)
                 return
 
+    click.echo(f"Successfully restarted the package {package_name}")
+
 
 def list_packages(local: bool):
     if not local:
@@ -400,7 +402,7 @@ def generate_logs(roe_client: RoeClient, package_name: str, tail: str = None):
 
     logs_dir = os.path.join(init_utils.ROE_DIR, "logs")
     if not os.path.isdir(logs_dir):
-        os.mkdir(logs_dir)
+        os.makedirs(logs_dir)
 
     raw_logs = roe_client.logs(package_name, tail)
     logs_text = raw_logs.replace("\n\n", "\n").replace("\n\n", "\n")
