@@ -2,6 +2,7 @@ import os
 
 from click.testing import CliRunner
 
+from roe.commands import cmd_deploy, cmd_stop
 from roe.commands.cmd_begin import cli
 from roe.utilities import errors
 
@@ -84,3 +85,12 @@ def test_begin_bad_creds_input_no_saved():
     assert isinstance(result.exception, errors.BadCredError)
     assert "Provided credentials file failed to authenticate." in result.output
     assert "ROE is now ready" not in result.output
+
+
+def test_begin_stopped():
+    runner = CliRunner()
+    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'./samples/simple_test'])
+    runner.invoke(cmd_stop.cli, ["-l", "-p", "simple_test"])
+    result = runner.invoke(cli, ['-l'], input='y\n')
+    assert not result.exception
+    assert 'Would you like to start all stopped packages? Enter Y to confirm:' in result.output
