@@ -1,6 +1,6 @@
 from click.testing import CliRunner
 
-from roe.commands import cmd_begin
+from roe.commands import cmd_begin, cmd_deploy
 from roe.commands.cmd_end import cli
 from roe.utilities.errors import *
 
@@ -36,3 +36,11 @@ def test_end_base():
     result = runner.invoke(cli, "-l", input="y\n")
     assert not result.exception
     assert "ROE has ended. To restart, simply run the 'roe begin -l' command.\n" in result.output
+
+
+def test_end_stop():
+    runner = CliRunner()
+    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'./samples/simple_test'])
+    result = runner.invoke(cli, "-l", input="y\n")
+    assert not result.exception
+    assert "Would you like to stop all running packages? Enter Y to confirm:" in result.output
