@@ -29,14 +29,14 @@ def test_logs_missing_package():
     Tests when a package name is given that doesn't exist
     """
     runner = CliRunner()
-    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'samples/myProject'])
+    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'samples/simple_test'])
     result = runner.invoke(cli, ["-l", "roe-api"])
     assert isinstance(result.exception, errors.PackageExistenceError)
 
 
 def test_logs_success():
     runner = CliRunner()
-    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'samples/myProject'])
-    result = runner.invoke(cli, ["-l", "myProject"])
+    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'samples/simple_test'])
+    result = runner.invoke(cli, ["-l", "simple_test"])
     assert not result.exception
     assert "Logs are available at: " in result.output
