@@ -19,8 +19,8 @@ def test_stop_base():
     Tests the stopping of a deployed package
     """
     runner = CliRunner()
-    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'./samples/myProject'])
-    result = runner.invoke(cli, ["-l", "-p", "myProject"])
+    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'./samples/simple_test'])
+    result = runner.invoke(cli, ["-l", "-p", "simple_test"])
     assert not result.exception
     assert "package has been stopped" in result.output
 
@@ -30,7 +30,7 @@ def test_stop_missing_input():
     Tests running command with no input
     """
     runner = CliRunner()
-    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'./samples/myProject'])
+    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'./samples/simple_test'])
     result = runner.invoke(cli, ["-l"])
     assert isinstance(result.exception, MissingPackageInputError)
     assert "Please specify a package name or --all." in result.output
\ No newline at end of file
